@@ -30,6 +30,7 @@ static int s_intensity;
 static int s_underline;
 static int s_blink;
 static int s_reverse;
+static int s_offset;
 
 #ifndef NPAR
 #define NPAR 10
@@ -37,8 +38,6 @@ static int s_reverse;
 static int npar;
 static int par[NPAR];
 
-static int scrolled=-1;
-
 #define ERASE_CHARACTER (ATTR_NORMAL<<8 | ' ')
 
 static void gotoxy(new_x, new_y)
@@ -46,7 +45,7 @@ static void gotoxy(new_x, new_y)
     x = new_x;
     y = new_y;
 
-    offset = (y*VIDEO_COLS + x) * 2 - base; //??PJC
+    offset = (y*VIDEO_COLS + x) * 2;
     set_cursor(offset);
 }
 
@@ -401,6 +400,7 @@ static void save_cur ()
   s_underline = underline;
   s_blink = blink;
   s_reverse = reverse;
+  s_offset = offset;
 }
 
 static void restore_cur ()
@@ -410,7 +410,9 @@ static void restore_cur ()
   underline = s_underline;
   blink = s_blink;
   reverse = s_reverse;
+  offset = s_offset;
   update_attr ();
+  
 }
 
 static void reset_terminal ()
@@ -665,7 +667,7 @@ static void vt100_write (unsigned char c)
 		case '@':
 		    csi_at ( par[0]);
 		    break;
-		case ']':	/* setterm functions */
+		case ']':
 		    /*	  setterm_command (); */
 		    break;
 		}
@@ -693,16 +695,8 @@ static void vt100_write (unsigned char c)
     /* Do we need to scroll? */
     
     if (offset >= VIDEOSCREEN_SIZE)
-    { 
-	if (scrolled != y)  /* then we haven't scrolled yet */
-	{
-	    offset = scroll_screen();
-    	    scrolled=y;
-	}
-	else /* we have; offset is wrong */
-	{
-    	    offset = VIDEOSCREEN_SIZE - VIDEO_LINELENGTH + (x*2);
-	}
+    {
+	offset = scroll_screen();
     }
     set_cursor(offset);
     
